PlaylistMemberModel class

Represents a single song entry within a playlist.

Constructors

PlaylistMemberModel({required int id, required int playlistId, required int audioId, int? playOrder, String? title, String? artist})
const
PlaylistMemberModel.fromMap(Map map)
factory

Properties

artist String?
Artist of the song.
final
audioId int
ID of the audio/song.
final
hashCode int
The hash code for this object.
no setterinherited
id int
Unique ID of this member row.
final
playlistId int
ID of the parent playlist.
final
playOrder int?
Play order (position) within the playlist (0-based).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title of the song.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited