DeviceAudioQueryPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DeviceAudioQueryPlatform
Implementers

Constructors

DeviceAudioQueryPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPermission() Future<PermissionStatus>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryAlbums({AlbumSortType sortType = AlbumSortType.album, OrderType orderType = OrderType.asc}) Future<List<AlbumModel>>
queryArtists({ArtistSortType sortType = ArtistSortType.artist, OrderType orderType = OrderType.asc}) Future<List<ArtistModel>>
queryArtwork({required int id, required ArtworkType type, ArtworkFormat format = ArtworkFormat.jpeg, int size = 200}) Future<Uint8List?>
queryAudiosWith({required AudiosFrom from, required int fromId, SongSortType sortType = SongSortType.title, OrderType orderType = OrderType.asc}) Future<List<SongModel>>
queryPlaylistMembers({required int playlistId}) Future<List<PlaylistMemberModel>>
queryPlaylists({PlaylistSortType sortType = PlaylistSortType.playlist, OrderType orderType = OrderType.asc}) Future<List<PlaylistModel>>
querySongs({SongSortType sortType = SongSortType.title, OrderType orderType = OrderType.asc, UriType uriType = UriType.external, String? path}) Future<List<SongModel>>
requestPermission() Future<PermissionStatus>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DeviceAudioQueryPlatform
The default instance of DeviceAudioQueryPlatform to use.
getter/setter pair