AlbumModel class
Represents an album on the device.
Constructors
- AlbumModel({required int id, required String album, String? artist, int? artistId, int? numOfSongs, String? albumArtUri, int? year})
-
const
- AlbumModel.fromMap(Map map)
-
factory
Properties
- album → String
-
Album title.
final
- albumArtUri → String?
-
URI to the album art.
final
- artist → String?
-
Primary artist of the album.
final
- artistId → int?
-
Artist ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier of the album.
final
- numOfSongs → int?
-
Number of songs in this album.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- year → int?
-
Year the album was released.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited