PlaylistModel class
Represents a playlist on the device.
Constructors
- PlaylistModel({required int id, required String playlist, int? numOfSongs, int? dateAdded, int? dateModified})
-
const
- PlaylistModel.fromMap(Map map)
-
factory
Properties
- dateAdded → int?
-
Date the playlist was created (Unix timestamp in seconds).
final
- dateModified → int?
-
Date the playlist was last modified (Unix timestamp in seconds).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique identifier of the playlist.
final
- numOfSongs → int?
-
Number of songs in the playlist.
final
- playlist → String
-
Playlist name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited