MethodChannelDeviceAudioQuery class
An implementation of DeviceAudioQueryPlatform using Flutter method channels.
- Inheritance
-
- Object
- PlatformInterface
- DeviceAudioQueryPlatform
- MethodChannelDeviceAudioQuery
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkPermission(
) → Future< PermissionStatus> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryAlbums(
{AlbumSortType sortType = AlbumSortType.album, OrderType orderType = OrderType.asc}) → Future< List< AlbumModel> > -
override
-
queryArtists(
{ArtistSortType sortType = ArtistSortType.artist, OrderType orderType = OrderType.asc}) → Future< List< ArtistModel> > -
override
-
queryArtwork(
{required int id, required ArtworkType type, ArtworkFormat format = ArtworkFormat.jpeg, int size = 200}) → Future< Uint8List?> -
override
-
queryAudiosWith(
{required AudiosFrom from, required int fromId, SongSortType sortType = SongSortType.title, OrderType orderType = OrderType.asc}) → Future< List< SongModel> > -
override
-
queryPlaylistMembers(
{required int playlistId}) → Future< List< PlaylistMemberModel> > -
override
-
queryPlaylists(
{PlaylistSortType sortType = PlaylistSortType.playlist, OrderType orderType = OrderType.asc}) → Future< List< PlaylistModel> > -
override
-
querySongs(
{SongSortType sortType = SongSortType.title, OrderType orderType = OrderType.asc, UriType uriType = UriType.external, String? path}) → Future< List< SongModel> > -
override
-
requestPermission(
) → Future< PermissionStatus> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited